* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Additional Resources](https://help.sap.com/docs/leanix/ea/additional-resources)
  * Welcome to the New Home of SAP LeanIX Documentation
